gfortran: Fortran compiler from the GNU Compiler Collection
===========================================================

Description
-----------

The GNU Compiler Collection, including the C, C++ and Fortran compiler.
This particular package is meant to only make gfortran available.

License
-------

GPL version 2 or version 3


Upstream Contact
----------------

http://gcc.gnu.org/

Dependencies
------------

-  zlib
-  MPIR
-  MPFR
-  MPC


Special Update/Build Instructions
---------------------------------

None.
